@@ -5,7 +5,7 @@ package CGI::Formalware;
 #	Convert an XML file into a suite of CGI forms.
 #
 # Test environment:
-#	Apache V 1.3.4 for Windows.
+#	Apache V 1.3.4, 1.3.6, 1.3.9 for Windows.
 # -----------------------------------------------------------------
 
 use integer;
@@ -23,7 +23,7 @@ require Exporter;
 
 @EXPORT = qw();
 
-$VERSION = '1.07';
+$VERSION = '1.08';
 
 # Preloaded methods go here.
 # -----------------------------------------------------------------
@@ -139,9 +139,15 @@ sub endHandlerPhase2
 
 	if ($element =~ /^form$/i)
 	{
-		# Override here does not stop the first 1 being the default.
+		# Due to bugs in CGI.pm, the override and default
+		# options must appear before the value option.
+		# Also, the override and default options must be used
+		# when there is only 1 radio button. If not, then the
+		# one and only is not selected.
 		push(@{$$html{$formCountPhase2} }, '<TR>', '<TD>',
 			radio_group({'name' => SCRIPT_HEADING_STRING, 'cols' => 1,
+			'override' => 1,
+			'default' => ${$scriptHeadingMenu{$formCountPhase2} }[0],
 			'value' => \@{$scriptHeadingMenu{$formCountPhase2} } }),
 			'</TD>', '</TR>');
 
@@ -242,10 +248,10 @@ sub endHandlerPhase2
 		my($number)	= '';
 		$number		= sprintf("%2i: ", $scriptCount{$formCountPhase2})
 			if ($numberScripts{$formCountPhase2});
-
-		push(@{$scriptHeadingMenu{$formCountPhase2} }, "$number$$attribute{'heading'}");
-		${$script{$formCountPhase2} }{$$attribute{'heading'} }		= $script;
-		${$scriptType{$formCountPhase2} }{$$attribute{'heading'} }	= $$attribute{'type'};
+		$number		= "$number$$attribute{'heading'}";
+		push(@{$scriptHeadingMenu{$formCountPhase2} }, $number);
+		${$script{$formCountPhase2} }{$number}		= $script;
+		${$scriptType{$formCountPhase2} }{$number}	= $$attribute{'type'};
 	}
 
 	# Gather field names for substitution into scripts.
@@ -758,7 +764,8 @@ sub startHandlerPhase2
 
 	if ($element =~ /^scripts$/i)
 	{
-		$numberScripts{$formCountPhase2} = 1 if (defined($attribute{'numberScripts'}) );
+		$numberScripts{$formCountPhase2} = 1 if (defined($attribute{'numberScripts'}) &&
+												($attribute{'numberScripts'} =~ /Yes/i) );
 	}
 
 	&pushIndent();
@@ -1201,11 +1208,13 @@ does not look like HTML. This needs to be handled more cleanly.
 
 =head1 AUTHOR
 
-C<CGI::Formalware> was written by Ron Savage I<E<lt>rpsavage@ozemail.com.auE<gt>>
+C<CGI::Formalware> was written by Ron Savage I<E<lt>ron@savage.net.auE<gt>>
 in 1999.
 
 Copyright (c) 1999 Ron Savage.
 
+Available from http://savage.net.au/Perl.html.
+
 =head1 LICENCE
 
 This program is free software; you can redistribute it and/or modify it under
